==> ultiplayground-0.1.3.tar.gz: ultiplayground-0.1.3/README.md <==
# Python Playground

![CodeQL](https://github.com/UltiRequiem/python/workflows/CodeQL/badge.svg)
![PyTest](https://github.com/UltiRequiem/python/workflows/PyTest/badge.svg)
[![Code Style](https://img.shields.io/badge/Code%20Style-Black-000000.svg)](https://github.com/psf/black)
[![PyPi Version](https://img.shields.io/pypi/v/ultiplayground)](https://pypi.org/project/ultiplayground)
![Repo Size](https://img.shields.io/github/repo-size/ultirequiem/python?style=flat-square&label=Repo)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
![Lines of Code](https://img.shields.io/tokei/lines/github.com/UltiRequiem/python?color=blue&label=Total%20Lines)
[![GitMoji](https://img.shields.io/badge/Gitmoji-%F0%9F%8E%A8%20-FFDD67.svg)](https://gitmoji.dev)

![Cover](https://i.imgur.com/h9R7o2k.png)

Python is an interpreted high-level general-purpose programming language.

It is the first programming language I learned,
so I have quite a bit of experience with it.

I do some exercises and challenges every day in:
[UltiRequiem/daily-python-practice](https://github.com/UltiRequiem/daily-python-practice)

To manage dependencies and build this package,
I'm using [Poetry](https://python-poetry.org).

To test my functions I am using [Pytest](https://pytest.org)

And if you are curious my code
editor is [Neovim](https://github.com/UltiRequiem/UltiVim) :)

## Interesting Articles

- [Python Type Checking](https://realpython.com/python-type-checking)
- [Python's Instance, Class, and Static Methods Demystified](https://realpython.com/instance-class-and-static-methods-demystified)
- [Object-Oriented Programming (OOP) in Python 3](https://realpython.com/python3-object-oriented-programming)
- [Python Objects and Classes](https://www.programiz.com/python-programming/class)

## Interesting Questions

- [How can I access a classmethod from inside a class in Python](https://stackoverflow.com/questions/13900515)

### Readed Articles

- [Python Closures](https://www.programiz.com/python-programming/closure)
- [You should know this when developing python package](https://medium.com/@udiyosovzon/things-you-should-know-when-developing-python-package-5fefc1ea3606)

### Readed Questions

- [How to call a function within class?](https://stackoverflow.com/questions/5615648)

==> ultiplayground-0.1.4.tar.gz: ultiplayground-0.1.4/README.md <==
# Python Playground

![CodeQL](https://github.com/UltiRequiem/python/workflows/CodeQL/badge.svg)
![PyTest](https://github.com/UltiRequiem/python/workflows/PyTest/badge.svg)
[![Code Style](https://img.shields.io/badge/Code%20Style-Black-000000.svg)](https://github.com/psf/black)
[![PyPi Version](https://img.shields.io/pypi/v/ultiplayground)](https://pypi.org/project/ultiplayground)
![Repo Size](https://img.shields.io/github/repo-size/ultirequiem/python?style=flat-square&label=Repo)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
![Lines of Code](https://img.shields.io/tokei/lines/github.com/UltiRequiem/python?color=blue&label=Total%20Lines)
[![GitMoji](https://img.shields.io/badge/Gitmoji-%F0%9F%8E%A8%20-FFDD67.svg)](https://gitmoji.dev)

![Cover](https://i.imgur.com/h9R7o2k.png)

Python is an interpreted high-level general-purpose programming language.
It is the first programming language I learned,
so I have quite a bit of experience with it.

To manage dependencies and build this package
I'm using [Poetry](https://python-poetry.org),
and to test my functions [Pytest](https://pytest.org).
And if you are curious my code
editor is [Neovim](https://github.com/UltiRequiem/UltiVim).

Using [GitHub Actions](https://github.com/UltiRequiem/python/tree/main/.github/workflows)
every time that I push a commit, the project is analyzed using
[CodeQL](https://github.com/UltiRequiem/python/blob/main/.github/workflows/codeql-analysis.yml)
and tested with
[PyTest](https://github.com/UltiRequiem/python/blob/main/.github/workflows/pytest.yml).
Furthermore, every time I release a new version,
the package is automatically published to [PyPI](https://pypi.org/project/ultiplayground).

I do some exercises and challenges every day in:
[UltiRequiem/daily-python-practice](https://github.com/UltiRequiem/daily-python-practice)

## Interesting Articles

- [Python Type Checking](https://realpython.com/python-type-checking)
- [Python's Instance, Class, and Static Methods Demystified](https://realpython.com/instance-class-and-static-methods-demystified)
- [Object-Oriented Programming (OOP) in Python 3](https://realpython.com/python3-object-oriented-programming)
- [Python Objects and Classes](https://www.programiz.com/python-programming/class)

## Interesting Questions

- [How can I access a classmethod from inside a class in Python](https://stackoverflow.com/questions/13900515)

### Readed Articles

- [Python Closures](https://www.programiz.com/python-programming/closure)
- [You should know this when developing python package](https://medium.com/@udiyosovzon/things-you-should-know-when-developing-python-package-5fefc1ea3606)

### Readed Questions

- [How to call a function within class?](https://stackoverflow.com/questions/5615648)
